==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/LINEARREFERENCEDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour LINEARREFERENCEDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="LINEARREFERENCEDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTLENGTH" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTLENGTHUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARREFUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARREFPRECISION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GEOGRAPHICALREFERENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSPECTIONDIRECTIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLOWCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARCOSTWEIGHT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LRFFROMPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LRFTOPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARDIRECTIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEAREQUIPMENTTYPE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LINEARREFERENCEDETAILS_Type", propOrder = {
    "equipmentlength",
    "equipmentlengthuom",
    "linearrefuom",
    "linearrefprecision",
    "geographicalreference",
    "inspectiondirectioncode",
    "flowcode",
    "linearcostweight",
    "lrffrompoint",
    "lrftopoint",
    "lineardirectionid",
    "linearequipmenttype"
})
public class LINEARREFERENCEDETAILS_Type {

    @XmlElement(name = "EQUIPMENTLENGTH")
    protected QUANTITY equipmentlength;
    @XmlElement(name = "EQUIPMENTLENGTHUOM")
    protected String equipmentlengthuom;
    @XmlElement(name = "LINEARREFUOM")
    protected String linearrefuom;
    @XmlElement(name = "LINEARREFPRECISION")
    @XmlSchemaType(name = "nonNegativeInteger")
    protected BigInteger linearrefprecision;
    @XmlElement(name = "GEOGRAPHICALREFERENCE")
    protected String geographicalreference;
    @XmlElement(name = "INSPECTIONDIRECTIONCODE")
    protected String inspectiondirectioncode;
    @XmlElement(name = "FLOWCODE")
    protected String flowcode;
    @XmlElement(name = "LINEARCOSTWEIGHT")
    @XmlSchemaType(name = "nonNegativeInteger")
    protected BigInteger linearcostweight;
    @XmlElement(name = "LRFFROMPOINT")
    protected QUANTITY lrffrompoint;
    @XmlElement(name = "LRFTOPOINT")
    protected QUANTITY lrftopoint;
    @XmlElement(name = "LINEARDIRECTIONID")
    protected UCODEID_Type lineardirectionid;
    @XmlElement(name = "LINEAREQUIPMENTTYPE")
    protected TYPE_Type linearequipmenttype;

    /**
     * Obtient la valeur de la propriété equipmentlength.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getEQUIPMENTLENGTH() {
        return equipmentlength;
    }

    /**
     * Définit la valeur de la propriété equipmentlength.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setEQUIPMENTLENGTH(QUANTITY value) {
        this.equipmentlength = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentlengthuom.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTLENGTHUOM() {
        return equipmentlengthuom;
    }

    /**
     * Définit la valeur de la propriété equipmentlengthuom.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTLENGTHUOM(String value) {
        this.equipmentlengthuom = value;
    }

    /**
     * Obtient la valeur de la propriété linearrefuom.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLINEARREFUOM() {
        return linearrefuom;
    }

    /**
     * Définit la valeur de la propriété linearrefuom.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLINEARREFUOM(String value) {
        this.linearrefuom = value;
    }

    /**
     * Obtient la valeur de la propriété linearrefprecision.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getLINEARREFPRECISION() {
        return linearrefprecision;
    }

    /**
     * Définit la valeur de la propriété linearrefprecision.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setLINEARREFPRECISION(BigInteger value) {
        this.linearrefprecision = value;
    }

    /**
     * Obtient la valeur de la propriété geographicalreference.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGEOGRAPHICALREFERENCE() {
        return geographicalreference;
    }

    /**
     * Définit la valeur de la propriété geographicalreference.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGEOGRAPHICALREFERENCE(String value) {
        this.geographicalreference = value;
    }

    /**
     * Obtient la valeur de la propriété inspectiondirectioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINSPECTIONDIRECTIONCODE() {
        return inspectiondirectioncode;
    }

    /**
     * Définit la valeur de la propriété inspectiondirectioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINSPECTIONDIRECTIONCODE(String value) {
        this.inspectiondirectioncode = value;
    }

    /**
     * Obtient la valeur de la propriété flowcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFLOWCODE() {
        return flowcode;
    }

    /**
     * Définit la valeur de la propriété flowcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFLOWCODE(String value) {
        this.flowcode = value;
    }

    /**
     * Obtient la valeur de la propriété linearcostweight.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getLINEARCOSTWEIGHT() {
        return linearcostweight;
    }

    /**
     * Définit la valeur de la propriété linearcostweight.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setLINEARCOSTWEIGHT(BigInteger value) {
        this.linearcostweight = value;
    }

    /**
     * Obtient la valeur de la propriété lrffrompoint.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getLRFFROMPOINT() {
        return lrffrompoint;
    }

    /**
     * Définit la valeur de la propriété lrffrompoint.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setLRFFROMPOINT(QUANTITY value) {
        this.lrffrompoint = value;
    }

    /**
     * Obtient la valeur de la propriété lrftopoint.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getLRFTOPOINT() {
        return lrftopoint;
    }

    /**
     * Définit la valeur de la propriété lrftopoint.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setLRFTOPOINT(QUANTITY value) {
        this.lrftopoint = value;
    }

    /**
     * Obtient la valeur de la propriété lineardirectionid.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getLINEARDIRECTIONID() {
        return lineardirectionid;
    }

    /**
     * Définit la valeur de la propriété lineardirectionid.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setLINEARDIRECTIONID(UCODEID_Type value) {
        this.lineardirectionid = value;
    }

    /**
     * Obtient la valeur de la propriété linearequipmenttype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getLINEAREQUIPMENTTYPE() {
        return linearequipmenttype;
    }

    /**
     * Définit la valeur de la propriété linearequipmenttype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setLINEAREQUIPMENTTYPE(TYPE_Type value) {
        this.linearequipmenttype = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/LINEARREFERENCEDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for LINEARREFERENCEDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="LINEARREFERENCEDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTLENGTH" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTLENGTHUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARREFUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARREFPRECISION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GEOGRAPHICALREFERENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSPECTIONDIRECTIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLOWCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARCOSTWEIGHT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LRFFROMPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LRFTOPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARDIRECTIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEAREQUIPMENTTYPE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LINEARREFERENCEDETAILS_Type", propOrder = {
    "equipmentlength",
    "equipmentlengthuom",
    "linearrefuom",
    "linearrefprecision",
    "geographicalreference",
    "inspectiondirectioncode",
    "flowcode",
    "linearcostweight",
    "lrffrompoint",
    "lrftopoint",
    "lineardirectionid",
    "linearequipmenttype"
})
public class LINEARREFERENCEDETAILS_Type {

    @XmlElement(name = "EQUIPMENTLENGTH")
    protected QUANTITY equipmentlength;
    @XmlElement(name = "EQUIPMENTLENGTHUOM")
    protected String equipmentlengthuom;
    @XmlElement(name = "LINEARREFUOM")
    protected String linearrefuom;
    @XmlElement(name = "LINEARREFPRECISION")
    @XmlSchemaType(name = "nonNegativeInteger")
    protected BigInteger linearrefprecision;
    @XmlElement(name = "GEOGRAPHICALREFERENCE")
    protected String geographicalreference;
    @XmlElement(name = "INSPECTIONDIRECTIONCODE")
    protected String inspectiondirectioncode;
    @XmlElement(name = "FLOWCODE")
    protected String flowcode;
    @XmlElement(name = "LINEARCOSTWEIGHT")
    @XmlSchemaType(name = "nonNegativeInteger")
    protected BigInteger linearcostweight;
    @XmlElement(name = "LRFFROMPOINT")
    protected QUANTITY lrffrompoint;
    @XmlElement(name = "LRFTOPOINT")
    protected QUANTITY lrftopoint;
    @XmlElement(name = "LINEARDIRECTIONID")
    protected UCODEID_Type lineardirectionid;
    @XmlElement(name = "LINEAREQUIPMENTTYPE")
    protected TYPE_Type linearequipmenttype;

    /**
     * Gets the value of the equipmentlength property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getEQUIPMENTLENGTH() {
        return equipmentlength;
    }

    /**
     * Sets the value of the equipmentlength property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setEQUIPMENTLENGTH(QUANTITY value) {
        this.equipmentlength = value;
    }

    /**
     * Gets the value of the equipmentlengthuom property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTLENGTHUOM() {
        return equipmentlengthuom;
    }

    /**
     * Sets the value of the equipmentlengthuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTLENGTHUOM(String value) {
        this.equipmentlengthuom = value;
    }

    /**
     * Gets the value of the linearrefuom property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLINEARREFUOM() {
        return linearrefuom;
    }

    /**
     * Sets the value of the linearrefuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLINEARREFUOM(String value) {
        this.linearrefuom = value;
    }

    /**
     * Gets the value of the linearrefprecision property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getLINEARREFPRECISION() {
        return linearrefprecision;
    }

    /**
     * Sets the value of the linearrefprecision property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setLINEARREFPRECISION(BigInteger value) {
        this.linearrefprecision = value;
    }

    /**
     * Gets the value of the geographicalreference property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGEOGRAPHICALREFERENCE() {
        return geographicalreference;
    }

    /**
     * Sets the value of the geographicalreference property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGEOGRAPHICALREFERENCE(String value) {
        this.geographicalreference = value;
    }

    /**
     * Gets the value of the inspectiondirectioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINSPECTIONDIRECTIONCODE() {
        return inspectiondirectioncode;
    }

    /**
     * Sets the value of the inspectiondirectioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINSPECTIONDIRECTIONCODE(String value) {
        this.inspectiondirectioncode = value;
    }

    /**
     * Gets the value of the flowcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFLOWCODE() {
        return flowcode;
    }

    /**
     * Sets the value of the flowcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFLOWCODE(String value) {
        this.flowcode = value;
    }

    /**
     * Gets the value of the linearcostweight property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getLINEARCOSTWEIGHT() {
        return linearcostweight;
    }

    /**
     * Sets the value of the linearcostweight property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setLINEARCOSTWEIGHT(BigInteger value) {
        this.linearcostweight = value;
    }

    /**
     * Gets the value of the lrffrompoint property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getLRFFROMPOINT() {
        return lrffrompoint;
    }

    /**
     * Sets the value of the lrffrompoint property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setLRFFROMPOINT(QUANTITY value) {
        this.lrffrompoint = value;
    }

    /**
     * Gets the value of the lrftopoint property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getLRFTOPOINT() {
        return lrftopoint;
    }

    /**
     * Sets the value of the lrftopoint property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setLRFTOPOINT(QUANTITY value) {
        this.lrftopoint = value;
    }

    /**
     * Gets the value of the lineardirectionid property.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getLINEARDIRECTIONID() {
        return lineardirectionid;
    }

    /**
     * Sets the value of the lineardirectionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setLINEARDIRECTIONID(UCODEID_Type value) {
        this.lineardirectionid = value;
    }

    /**
     * Gets the value of the linearequipmenttype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getLINEAREQUIPMENTTYPE() {
        return linearequipmenttype;
    }

    /**
     * Sets the value of the linearequipmenttype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setLINEAREQUIPMENTTYPE(TYPE_Type value) {
        this.linearequipmenttype = value;
    }

}
